@@ -1,11 +1,11 @@
-## ----setup, echo=FALSE--------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(knitr)
 opts_chunk$set(
   warning = FALSE, message = FALSE,
   eval = requireNamespace("ggplot2", quietly = TRUE)             
 )
 
-## ----echo=FALSE---------------------------------------------------------------
+## -----------------------------------------------------------------------------
 library(ggplot2)
 theme_set(theme_light())
 
@@ -21,12 +21,12 @@ total_words <- book_words %>% group_by(book) %>% summarize(total = sum(n))
 book_words <- left_join(book_words, total_words)
 book_words
 
-## ---- fig.height=7, fig.width=7-----------------------------------------------
+## -----------------------------------------------------------------------------
 library(ggplot2)
 ggplot(book_words, aes(n/total, fill = book)) +
   geom_histogram(show.legend = FALSE) +
-  xlim(NA, 0.0009) +
-  facet_wrap(~book, ncol = 2, scales = "free_y")
+  scale_x_continuous(limits = c(NA, 0.0009)) +
+  facet_wrap(vars(book), ncol = 2, scales = "free_y")
 
 ## -----------------------------------------------------------------------------
 book_words <- book_words %>%
